<?php

// $Id$

/*
 * @author Adam Westerski 
 * @file ideastream_elements.module
 * ideastream_elements Module - user profile related functions
 */


/* 
 * Display "Ideas" panel in the user profile
 * The panel shows last posted ideas, sandbox ideas etc.
 */
function ideastream_elements_user_profile_ideas($form_state) {
	$page_html = "";

	$uid = arg(1);
  
  //$account = user_load(array('uid' => arg(1), 'status' => 1));
  if (isset($uid))
    $account = user_load($uid);
	if (isset($account)) {
		//$page_html .= "test";
    
		drupal_set_title(check_plain($account->name));
		
		$form['list_sandbox'] = array(
		'#type' => 'fieldset',
		'#title' => t('Sandbox Ideas'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A list of unpublished ideas saved as drafts.')
		);
		
		$form['list'] = array(
		'#type' => 'fieldset',
		'#title' => t('Published Ideas'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A full list of all posted ideas (does not include sandbox ideas).')
		);
				
		$form['user_profile']['profile_uid'] = array(	
			'#type' => 'hidden', 
			'#value' => $uid,
		);
		return $form;
	}
	return $page_html;
}

function theme_ideastream_elements_user_profile_ideas($form) {

  $form = $form['form'];
  $user_uid=$form['user_profile']['profile_uid']['#value'];
  $rows_per_page = 10;

  /***************************************************************** UNPUBLISHED IDEAS LIST  *****************************************************************************/
  // table header
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  );
  
  $rows = array();

  //create query
  $relationships = db_select('node', 'node')
  ->fields('node', array('nid', 'created', 'title'))
  ->condition('node.type', 'idea')
  ->condition('node.status', 0)
  ->condition('node.uid', $user_uid);

  //add pager and sorting queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
    $results = $relationships->execute();

  //go over results
  while ($item = $results->fetchAssoc()) {
  	$rows[] = array(
  		'#custom_idea_title' => l($item['title'], 'node/' . $item['nid']),
    		'#custom_idea_created' => format_date($item['created'], 'small')
  		);
  }
  
  //format output
  if (count($rows)>0)
    $form['list_sandbox']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 0));
  else $form['list_sandbox']['#description'] = t("Your Idea Sandbox is currently empty. You have no unpublished ideas.");

  /***************************************************************** PUBLISHED IDEAS LIST  *****************************************************************************/
  //table header
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  	array('data' => t('Comments'), 'field' => 'COMMENT_COUNT'),
  	array('data' => t('Rating'), 'field' => 'VOTE_VALUE'),
  );

  //clear previous data
  $rows = array();
  $relationships = NULL;
  $results = NULL;

  //prepare query
  $relationships = db_select('node', 'node');
  $relationships->leftJoin('node_comment_statistics', 'node_comment_statistics', 'node.nid = node_comment_statistics.nid');
  $relationships->leftJoin('votingapi_cache', 'votingapi_cache_node_points_sum', "node.nid = votingapi_cache_node_points_sum.entity_id AND votingapi_cache_node_points_sum.entity_type = 'node ' AND votingapi_cache_node_points_sum.value_type = 'points' AND votingapi_cache_node_points_sum.function = 'sum'");
  
  $relationships
  ->fields('node', array('nid', 'created', 'title'))
  //->fields('node_comment_statistics', array('comment_count'))
  //->fields('votingapi_cache_node_points_sum', array('value'))
  ->condition('node.type', 'idea')
  ->condition('node.status', 1)
  ->condition('node.uid', $user_uid); 

  $relationships -> addField('node_comment_statistics','comment_count','COMMENT_COUNT');
  $relationships -> addField('votingapi_cache_node_points_sum','value','VOTE_VALUE');

  
  //add pager and sort queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
  $results = $relationships->execute();

  //process results
  while ($item = $results->fetchAssoc()) {
  	$rows[] = array(
  		'#custom_idea_title' => l($item['title'], 'node/' . $item['nid']),
    		'#custom_idea_created' => format_date($item['created'], 'small'),
  		'#custom_comments' => $item['COMMENT_COUNT'],
  		'#custom_votes' => ($item['VOTE_VALUE'] ? $item['VOTE_VALUE'] : 0)
  		);
  }
   
  //format html 
  if (count($rows)>0)
    $form['list']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 1));
  else $form['list']['#description'] = t("Currently you don't have any published ideas.");
  
  return drupal_render_children($form);
}

// ******************************************** Reviews ***********************************************
// ****************************************************************************************************

/* 
 * Display "Reviews" panel in the user profile
 * The panel shows last posted ideas, sandbox ideas etc.
 */
function ideastream_elements_user_profile_reviews($form_state) {
	$page_html = "";

	$uid = arg(1);

  if (isset($uid))
    $account = user_load($uid);
  if (isset($account)) {
	//if ($account = user_load(array('uid' => arg(1), 'status' => 1))) {
		//$page_html .= "test";
		drupal_set_title(check_plain($account->name));
		
		$form['list_sandbox'] = array(
		'#type' => 'fieldset',
		'#title' => t('Sandbox Reviews'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A list of unpublished reviews saved as drafts.')
		);
		
		$form['list'] = array(
		'#type' => 'fieldset',
		'#title' => t('Published Reviews'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A full list of all posted reviews (does not include sandbox reviews).')
		);
				
		$form['user_profile']['profile_uid'] = array(	
			'#type' => 'hidden', 
			'#value' => $uid,
		);

		return $form;
	}
	return $page_html;
}

function theme_ideastream_elements_user_profile_reviews($form) {

  $form = $form['form'];
  $user_uid=$form['user_profile']['profile_uid']['#value'];
  $rows_per_page = 10;

  /**************************************************************** UNPUBLISHED REVIEWS LIST  *****************************************************************************/
    
  // theme list of unpublished ideas (sandbox)
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  	array('data' => t('Type'), 'field' => 'REVIEW_TYPE'),
  	array('data' => t('Rating'), 'field' => 'REVIEW_RATING'),
  	array('data' => t('Idea'), 'field' => 'IDEA_NID'),
  );
  
  $rows = array();

  //prepare query
  $relationships = db_select('node', 'node');
  $relationships->leftJoin('field_data_field_review_rating', 'field_data_field_review_rating', 'node.nid = field_data_field_review_rating.entity_id');
  $relationships->leftJoin('field_data_field_reviewed_idea', 'field_data_field_reviewed_idea', 'node.nid = field_data_field_reviewed_idea.entity_id');
  $relationships->leftJoin('field_data_field_review_type', 'field_data_field_review_type', 'node.nid = field_data_field_review_type.entity_id');
  $relationships->leftJoin('taxonomy_term_data', 'taxonomy_term_data', "field_data_field_review_type.field_review_type_tid = taxonomy_term_data.tid");
  $relationships->leftJoin('node', 'idea_table',"idea_table.nid = field_data_field_reviewed_idea.field_reviewed_idea_target_id");
  
  $relationships
  ->fields('node', array('nid', 'created', 'title'))
  ->condition('node.type', 'review')
  ->condition('node.status', 0)
  ->condition('node.uid', $user_uid); 

  $relationships -> addField('taxonomy_term_data','name','REVIEW_TYPE');
  $relationships -> addField('field_data_field_review_rating','field_review_rating_value','REVIEW_RATING');
  $relationships -> addField('idea_table','title','IDEA_TITLE');
  $relationships -> addField('idea_table','nid','IDEA_NID');
  
  //add pager and sort queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
  $results = $relationships->execute();

  //process results
  while ($item = $results->fetchAssoc()) {
  //while ($item = db_fetch_object($relationships)) {
    $rows[] = array(
      '#custom_review_title' => l($item['title'], 'node/' . $item['nid']),
      '#custom_review_created' => format_date($item['created'], 'small'),
      '#custom_review_type' => $item['REVIEW_TYPE'],
      '#custom_review_rating' => ($item['REVIEW_RATING'] ? $item['REVIEW_RATING'] : "-"),
      '#custom_review_idea' => l($item['IDEA_TITLE'], 'node/' . $item['IDEA_NID']),
      );
  }
    
  if (count($rows)>0)
  	//$form['list_sandbox']['#value'] = theme('table', $header, $rows) . theme('pager',NULL, $rows_per_page, 0);
    $form['list_sandbox']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 0));
  else $form['list_sandbox']['#description'] = t("Your Review Sandbox is currently empty. You have no unpublished reviews.");
  
  /****************************************************************** PUBLISHED REVIEWS LIST  *****************************************************************************/
  
  // theme list of published ideas
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  	array('data' => t('Type'), 'field' => 'REVIEW_TYPE'),
  	array('data' => t('Rating'), 'field' => 'REVIEW_RATING'),
  	array('data' => t('Idea'), 'field' => 'IDEA_NID'),
  );
  
  $rows = array();

  //prepare query
  $relationships = db_select('node', 'node');
  $relationships->leftJoin('field_data_field_review_rating', 'field_data_field_review_rating', 'node.nid = field_data_field_review_rating.entity_id');
  $relationships->leftJoin('field_data_field_reviewed_idea', 'field_data_field_reviewed_idea', 'node.nid = field_data_field_reviewed_idea.entity_id');
  $relationships->leftJoin('field_data_field_review_type', 'field_data_field_review_type', 'node.nid = field_data_field_review_type.entity_id');
  $relationships->leftJoin('taxonomy_term_data', 'taxonomy_term_data', "field_data_field_review_type.field_review_type_tid = taxonomy_term_data.tid");
  $relationships->leftJoin('node', 'idea_table',"idea_table.nid = field_data_field_reviewed_idea.field_reviewed_idea_target_id");
  
  $relationships
  ->fields('node', array('nid', 'created', 'title'))
  ->condition('node.type', 'review')
  ->condition('node.status', 1)
  ->condition('node.uid', $user_uid); 

  $relationships -> addField('taxonomy_term_data','name','REVIEW_TYPE');
  $relationships -> addField('field_data_field_review_rating','field_review_rating_value','REVIEW_RATING');
  $relationships -> addField('idea_table','title','IDEA_TITLE');
  $relationships -> addField('idea_table','nid','IDEA_NID');
  
  //add pager and sort queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
  $results = $relationships->execute();

  //process results
  while ($item = $results->fetchAssoc()) {
  //while ($item = db_fetch_object($relationships)) {
    $rows[] = array(
      '#custom_review_title' => l($item['title'], 'node/' . $item['nid']),
      '#custom_review_created' => format_date($item['created'], 'small'),
      '#custom_review_type' => $item['REVIEW_TYPE'],
      '#custom_review_rating' => ($item['REVIEW_RATING'] ? $item['REVIEW_RATING'] : "-"),
      '#custom_review_idea' => l($item['IDEA_TITLE'], 'node/' . $item['IDEA_NID']),
      );
  }
  if (count($rows)>0)
    $form['list']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 1));
	  //$form['list']['#value'] = theme('table', $header, $rows) . theme('pager',NULL, $rows_per_page, 1);
  else $form['list']['#description'] = t("Currently you don't have any published reviews.");
  
  //return drupal_render($form);
  return drupal_render_children($form);
}

// ******************************************** Contests ***********************************************
// *****************************************************************************************************

/* 
 * Display "Contests" panel in the user profile
 * The panel shows last posted ideas, sandbox ideas etc.
 */
function ideastream_elements_user_profile_contests($form_state) {
	$page_html = "";

  $uid = arg(1);
  
  //$account = user_load(array('uid' => arg(1), 'status' => 1));
  if (isset($uid))
    $account = user_load($uid);
  if (isset($account)) {
	//if ($account = user_load(array('uid' => arg(1), 'status' => 1))) {
		//$page_html .= "test";
		drupal_set_title(check_plain($account->name));
		
		$form['list_sandbox'] = array(
		'#type' => 'fieldset',
		'#title' => t('Sandbox Contests'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A list of unpublished contests saved as drafts.')
		);
		
		$form['list'] = array(
		'#type' => 'fieldset',
		'#title' => t('Published Contests'),
		'#collapsible' => FALSE,
		'#collapsed' => FALSE,
		'#tree' => FALSE,
		'#description' => t('A full list of all posted contests (does not include sandbox contests).')
		);
				
		$form['user_profile']['profile_uid'] = array(	
			'#type' => 'hidden', 
			'#value' => $uid,
		);

		return $form;
	}
	return $page_html;
}

function theme_ideastream_elements_user_profile_contests($form) {

  $form = $form['form'];
  $user_uid = $form['user_profile']['profile_uid']['#value'];
  $rows_per_page = 10;

  /*************************************************************** UNPUBLISHED CONTESTS LIST  *****************************************************************************/
  // theme list of unpublished ideas (sandbox)
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  	array('data' => t('State'), 'field' => 'state'),
  	array('data' => t('Ideas'), 'field' => 'IDEA_COUNT'),
  );
  
  $rows = array();


//   $count_query = "SELECT count(node.nid) FROM node WHERE type='contest' AND node.status=0 AND node.uid = $user_uid";
  
//   $relationships = pager_query("SELECT node.nid, node.title, node.created, workflow_states.state, COUNT(content_type_idea.nid) AS IDEA_COUNT FROM node 
// LEFT JOIN workflow_node ON node.nid = workflow_node.nid 
// LEFT JOIN workflow_states ON workflow_node.sid = workflow_states.sid
// LEFT JOIN content_type_idea ON node.nid = content_type_idea.field_idea_contest_nid WHERE node.type='contest' AND node.uid = $user_uid AND node.status=0 GROUP BY node.nid".tablesort_sql($header),$rows_per_page,1,$count_query);

  //prepare query
  $relationships = db_select('node', 'node');
  $relationships->leftJoin('workflow_node', 'workflow_node', 'node.nid = workflow_node.nid ');
  $relationships->leftJoin('workflow_states', 'workflow_states', 'workflow_node.sid = workflow_states.sid');
  $relationships->leftJoin('field_data_field_idea_contest', 'field_data_field_idea_contest', 'node.nid = field_data_field_idea_contest.field_idea_contest_target_id');
  
  $relationships
  ->fields('node', array('nid', 'created', 'title'))
  ->fields('workflow_states', array('state'))
  ->condition('node.type', 'contest')
  ->condition('node.status', 0)
  ->condition('node.uid', $user_uid); 

  $relationships -> addExpression('COUNT(field_data_field_idea_contest.entity_id)', 'IDEA_COUNT');
  $relationships -> groupBy('node.nid');
  
  //add pager and sort queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
  $results = $relationships->execute();

  //process results
  while ($item = $results->fetchAssoc()) {
    	$rows[] = array(
    		'#custom_review_title' => l($item['title'], 'node/' . $item['nid']),
      		'#custom_review_created' => format_date($item['created'], 'small'),
    		'#custom_review_type' => $item['state'],
    		'#custom_review_rating' => ($item['IDEA_COUNT'] ? $item['IDEA_COUNT'] : "0"),
    		);
    }
    
  if (count($rows)>0)
    $form['list_sandbox']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 0));
  	//$form['list_sandbox']['#value'] = theme('table', $header, $rows) . theme('pager',NULL, $rows_per_page, 0);
  else $form['list_sandbox']['#description'] = t("Your Contest Sandbox is currently empty. You have no unpublished contests.");
  
  // theme list of published ideas
  $header = array(
  	array('data' => t('Title'), 'field' => 'title'),
  	array('data' => t('Date'), 'field' => 'created', 'sort' => 'desc'),
  	array('data' => t('State'), 'field' => 'state'),
  	array('data' => t('Ideas'), 'field' => 'IDEA_COUNT'),
  );
  
  $rows = array();

//   $count_query = "SELECT count(node.nid) FROM node WHERE type='contest' AND node.status=1 AND node.uid = $user_uid";
  
//   $relationships = pager_query("SELECT node.nid, node.title, node.created, workflow_states.state, COUNT(content_type_idea.nid) AS IDEA_COUNT FROM node 
// LEFT JOIN workflow_node ON node.nid = workflow_node.nid 
// LEFT JOIN workflow_states ON workflow_node.sid = workflow_states.sid
// LEFT JOIN content_type_idea ON node.nid = content_type_idea.field_idea_contest_nid WHERE node.type='contest' AND node.uid = $user_uid AND node.status=1 GROUP BY node.nid".tablesort_sql($header),$rows_per_page,1,$count_query);

  //prepare query
  $relationships = db_select('node', 'node');
  $relationships->leftJoin('workflow_node', 'workflow_node', 'node.nid = workflow_node.nid ');
  $relationships->leftJoin('workflow_states', 'workflow_states', 'workflow_node.sid = workflow_states.sid');
  $relationships->leftJoin('field_data_field_idea_contest', 'field_data_field_idea_contest', 'node.nid = field_data_field_idea_contest.field_idea_contest_target_id');
  
  $relationships
  ->fields('node', array('nid', 'created', 'title'))
  ->fields('workflow_states', array('state'))
  ->condition('node.type', 'contest')
  ->condition('node.status', 1)
  ->condition('node.uid', $user_uid); 

  $relationships -> addExpression('COUNT(field_data_field_idea_contest.entity_id)', 'IDEA_COUNT');
  $relationships -> groupBy('node.nid');
  
  //add pager and sort queries
  $relationships = $relationships -> extend('PagerDefault');
  $relationships = $relationships -> limit($rows_per_page);
  $relationships = $relationships -> extend('TableSort');
  $relationships = $relationships -> orderByHeader($header);

  //execute query
  $results = $relationships->execute();

  //process results
  while ($item = $results->fetchAssoc()) {
  	$rows[] = array(
        '#custom_review_title' => l($item['title'], 'node/' . $item['nid']),
          '#custom_review_created' => format_date($item['created'], 'small'),
        '#custom_review_type' => $item['state'],
        '#custom_review_rating' => ($item['IDEA_COUNT'] ? $item['IDEA_COUNT'] : "0"),
  		);
  }
  if (count($rows)>0)
    $form['list']['#value'] = theme('table', array('header' => $header, 'rows' => $rows)) . theme('pager', array('element' => 1));
	  //$form['list']['#value'] = theme('table', $header, $rows) . theme('pager',NULL, $rows_per_page, 1);
  else $form['list']['#description'] = t("Currently you don't have any published contests.");
  
  return drupal_render_children($form);
}

?>