<?php

/**
 * Override of theme_breadcrumb().
 */
function ideastream_d7_breadcrumb($variables) {
  $breadcrumb = $variables['breadcrumb'];

  if (!empty($breadcrumb)) {
    // Provide a navigational heading to give context for breadcrumb links to
    // screen-reader users. Make the heading invisible with .element-invisible.
    $output = '<h2 class="element-invisible">' . t('You are here') . '</h2>';

    $output .= '<div class="breadcrumb">' . implode(' › ', $breadcrumb) . '</div>';
    return $output;
  }
}

/**
 * Override or insert variables into the maintenance page template.
 */
function ideastream_d7_preprocess_maintenance_page(&$vars) {
  // While markup for normal pages is split into page.tpl.php and html.tpl.php,
  // the markup for the maintenance page is all in the single
  // maintenance-page.tpl.php template. So, to have what's done in
  // ideastream_d7_preprocess_html() also happen on the maintenance page, it has to be
  // called here.
  ideastream_d7_preprocess_html($vars);
}

/**
 * Override or insert variables into the html template.
 */
function ideastream_d7_preprocess_html(&$vars) {
  // Toggle fixed or fluid width.
  if (theme_get_setting('ideastream_d7_width') == 'fluid') {
    $vars['classes_array'][] = 'fluid-width';
  }
  // Add conditional CSS for IE6.
  drupal_add_css(path_to_theme() . '/fix-ie.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'lt IE 7', '!IE' => FALSE), 'preprocess' => FALSE));
}

/**
 * Override or insert variables into the html template.
 */
function ideastream_d7_process_html(&$vars) {
  // Hook into color.module
  if (module_exists('color')) {
    _color_html_alter($vars);
  }
}

/**
 * Override or insert variables into the page template.
 */
function ideastream_d7_preprocess_page(&$vars) {
  // Move secondary tabs into a separate variable.
  $vars['tabs2'] = array(
    '#theme' => 'menu_local_tasks',
    '#secondary' => $vars['tabs']['#secondary'],
  );
  unset($vars['tabs']['#secondary']);

  if (isset($vars['main_menu'])) {
    $vars['primary_nav'] = theme('links__system_main_menu', array(
      'links' => $vars['main_menu'],
      'attributes' => array(
        'class' => array('links', 'inline', 'main-menu'),
      ),
      'heading' => array(
        'text' => t('Main menu'),
        'level' => 'h2',
        'class' => array('element-invisible'),
      )
    ));
  }
  else {
    $vars['primary_nav'] = FALSE;
  }
  if (isset($vars['secondary_menu'])) {
    $vars['secondary_nav'] = theme('links__system_secondary_menu', array(
      'links' => $vars['secondary_menu'],
      'attributes' => array(
        'class' => array('links', 'inline', 'secondary-menu'),
      ),
      'heading' => array(
        'text' => t('Secondary menu'),
        'level' => 'h2',
        'class' => array('element-invisible'),
      )
    ));
  }
  else {
    $vars['secondary_nav'] = FALSE;
  }

  // Prepare header.
  $site_fields = array();
  if (!empty($vars['site_name'])) {
    $site_fields[] = $vars['site_name'];
  }
  if (!empty($vars['site_slogan'])) {
    $site_fields[] = $vars['site_slogan'];
  }
  $vars['site_title'] = implode(' ', $site_fields);
  if (!empty($site_fields)) {
    $site_fields[0] = '<span>' . $site_fields[0] . '</span>';
  }
  $vars['site_html'] = implode(' ', $site_fields);

  // Set a variable for the site name title and logo alt attributes text.
  $slogan_text = $vars['site_slogan'];
  $site_name_text = $vars['site_name'];
  $vars['site_name_and_slogan'] = $site_name_text . ' ' . $slogan_text;
}

/**
 * Override or insert variables into the node template.
 */
function ideastream_d7_preprocess_node(&$vars) {
  $vars['submitted'] = $vars['date'] . ' — ' . $vars['name'];
}

/**
 * Override or insert variables into the comment template.
 */
function ideastream_d7_preprocess_comment(&$vars) {
  $vars['submitted'] = $vars['created'] . ' — ' . $vars['author'];
}

/**
 * Override or insert variables into the block template.
 */
function ideastream_d7_preprocess_block(&$vars) {
  $vars['title_attributes_array']['class'][] = 'title';
  $vars['classes_array'][] = 'clearfix';
}

/*
 * Search form customization
 */
 
function ideastream_d7_preprocess_search_block_form(&$vars) {
//var_dump($vars);
	// Modify elements of the search form
	unset($vars['form']['search_block_form']['#title']);

	// Set a default value for the search box
  $vars['form']['search_block_form']['#value'] = t('Search ideas...');
  	
	// Add a custom class to the search box
	// Set yourtheme.css > #search-block-form .form-text { color: #888888; }
  $vars['form']['search_block_form']['#attributes'] = array(
  	 'onblur' => "if (this.value == '') {this.value = '".$vars['form']['search_block_form']['#value']."';} this.style.color = '#000000';", 
		 'onfocus' => "if (this.value == '".$vars['form']['search_block_form']['#value']."') {this.value = '';} this.style.color = '#000000';" );

	// Modify elements of the submit button
	unset($vars['form']['submit']);

	// Change text on the submit button
	//$vars['form']['submit']['#value'] = t('Go!');

	// Change submit button into image button - NOTE: '#src' leading '/' automatically added
	$vars['form']['submit']['image_button'] = null; //array('#type' => 'image_button', '#src' => 'sites/all/themes/yourtheme/images/search-button.png');
	
	//Drupal 7 version
  	unset($vars['form']["search"]["actions"]);
	unset($vars['form']["actions"]);

	// Rebuild the rendered version (search form only, rest remains unchanged)
  unset($vars['form']['search_block_form']['#printed']);
  $vars['search']['search_block_form'] = drupal_render($vars['form']['search_block_form']);

	// Rebuild the rendered version (submit button, rest remains unchanged)
	//unset($vars['form']['submit']['#printed']);
	//$vars['search']['submit'] = drupal_render($vars['form']['submit']);
	
	//Drupal 7 version
	unset($vars['form']['actions']['#printed']);
	$vars['search']['actions'] = drupal_render($vars['form']['actions']);
	
	// Collect all form elements to print entire form
  $vars['search_form'] = implode($vars['search']);
}

/**
* Implements hook_form_FORM_ID_alter().
*/
function ideastream_d7_form_user_login_block_alter(&$form) {	
	$form['name']['#title'] = '';
	$form['pass']['#title'] = '';
  	$form['name']['#default_value'] = t("Username");
  	$form['pass']['#default_value'] = t("Password");

  if (!preg_match('/\bmsie 7/i', $_SERVER['HTTP_USER_AGENT'])) {
	  $form['pass']['#type'] = "textfield";
	  
  	  $form['name']['#attributes']['OnClick'] = 'this.value=""';
	  $form['pass']['#attributes']['OnClick'] = 'this.value=""; this.type="password";';
  	  $form['pass']['#attributes']['OnFocus'] = 'this.value=""; this.type="password";';
  } else //in internet explorer 7 changing input type does not work so always keep the input as password
  {  		
  	  //$form['name']['#value'] = "";
  	  $form['name']['#attributes']['OnClick'] = 'this.value=""';
	  $form['pass']['#attributes']['OnClick'] = 'this.value="";';
  	  $form['pass']['#attributes']['OnFocus'] = 'this.value="";';
  }
  	
	unset($form['links']); //remove links under fields
}

/**
 * Override or insert variables into the page template.
 */
function ideastream_d7_process_page(&$vars) {
  // Hook into color.module
  if (module_exists('color')) {
    _color_page_alter($vars);
  }
}

/**
 * Override or insert variables into the region template.
 */
function ideastream_d7_preprocess_region(&$vars) {
  if ($vars['region'] == 'header') {
    $vars['classes_array'][] = 'clearfix';
  }
}
